Update version numnering to the ratified format.
Update the number for the point release.

Signed-off-by: Mike Holmes <[email protected]>
---
 configure.ac                                     |  2 +-
 platform/linux-generic/include/api/odp_version.h | 28 ++++++++++++++++--------
 2 files changed, 20 insertions(+), 10 deletions(-)

diff --git a/configure.ac b/configure.ac
index aa94034..cc92013 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1,5 +1,5 @@
 AC_PREREQ([2.5])
-AC_INIT([OpenDataPlane], [0.2], [[email protected]])
+AC_INIT([OpenDataPlane], [0.3.0.0], [[email protected]])
 AM_INIT_AUTOMAKE([subdir-objects])
 AC_CONFIG_SRCDIR([helper/config.h.in])
 AM_CONFIG_HEADER([helper/config.h])
diff --git a/platform/linux-generic/include/api/odp_version.h 
b/platform/linux-generic/include/api/odp_version.h
index 3a75201..5b90e32 100644
--- a/platform/linux-generic/include/api/odp_version.h
+++ b/platform/linux-generic/include/api/odp_version.h
@@ -23,29 +23,38 @@ extern "C" {
  */
 
 /**
- * ODP API main version
+ * ODP API generation version
+ *
+ * Introduction of major new features or changes that make
+ * very significatant changes to the API. APIs with different
+ * versions are likely not backward compatible.
+ */
+#define ODP_VERSION_API_GENERATION 0
+
+/**
+ * ODP API major version
  *
  * Introduction of major new features or changes. APIs with different major
  * versions are likely not backward compatible.
  */
-#define ODP_VERSION_API_MAIN  0
+#define ODP_VERSION_API_MAJOR 3
 
 /**
  * ODP API sub version
  *
  * Introduction of additional features or minor changes. APIs with common
  * major version and different sub versions may be backward compatible (if only
  * additions).
  */
-#define ODP_VERSION_API_SUB   0
+#define ODP_VERSION_API_MINOR 0
 
 /**
- * ODP API bug correction version
+ * ODP API sub correction version
  *
  * Bug corrections to the API files. APIs with the same major and sub
  * versions, but different bug correction versions are backward compatible.
  */
-#define ODP_VERSION_API_BUG   1
+#define ODP_VERSION_API_SUB 0
 
 
 /** @internal Version string expand */
@@ -56,9 +65,10 @@ extern "C" {
 
 /** @internal API version string */
 #define ODP_VERSION_API_STR \
-ODP_VERSION_TO_STR(ODP_VERSION_API_MAIN) "."\
-ODP_VERSION_TO_STR(ODP_VERSION_API_SUB) "."\
-ODP_VERSION_TO_STR(ODP_VERSION_API_BUG)
+ODP_VERSION_TO_STR(ODP_VERSION_API_GENERATION) "."\
+ODP_VERSION_TO_STR(ODP_VERSION_API_MAJOR) "."\
+ODP_VERSION_TO_STR(ODP_VERSION_API_MINOR) "."\
+ODP_VERSION_TO_STR(ODP_VERSION_API_SUB)
 
 
 /**
@@ -23,29 +23,38 @@ extern "C" {
 
 /**
- * ODP API sub version
+ * ODP API minor version
  *
  * Introduction of additional features or minor changes. APIs with common
-- 
1.9.1


_______________________________________________
lng-odp mailing list
[email protected]
http://lists.linaro.org/mailman/listinfo/lng-odp

Reply via email to